[orca] Fix for bug 665223 - WebKitGtk-based app scripts should be consolidated



commit 638dec5c6e28c8283d1cee1397bf0edc26b1a285
Author: Joanmarie Diggs <jdiggs igalia com>
Date:   Wed Nov 30 17:49:26 2011 +0100

    Fix for bug 665223 - WebKitGtk-based app scripts should be consolidated

 configure.ac                                  |    2 -
 src/orca/script_manager.py                    |    2 -
 src/orca/scripts/apps/Makefile.am             |    4 +-
 src/orca/scripts/apps/__init__.py             |    4 +-
 src/orca/scripts/apps/epiphany/Makefile.am    |    7 ---
 src/orca/scripts/apps/epiphany/__init__.py    |   20 -------
 src/orca/scripts/apps/epiphany/script.py      |   70 -------------------------
 src/orca/scripts/apps/yelp/Makefile.am        |    7 ---
 src/orca/scripts/apps/yelp/__init__.py        |   28 ----------
 src/orca/scripts/apps/yelp/script.py          |   64 ----------------------
 src/orca/scripts/toolkits/WebKitGtk/script.py |   35 +++++++++++-
 11 files changed, 34 insertions(+), 209 deletions(-)
---
diff --git a/configure.ac b/configure.ac
index d314cc1..8aea06d 100644
--- a/configure.ac
+++ b/configure.ac
@@ -88,7 +88,6 @@ src/orca/scripts/apps/ddu/Makefile
 src/orca/scripts/apps/Eclipse/Makefile
 src/orca/scripts/apps/ekiga/Makefile
 src/orca/scripts/apps/empathy/Makefile
-src/orca/scripts/apps/epiphany/Makefile
 src/orca/scripts/apps/evolution/Makefile
 src/orca/scripts/apps/gajim/Makefile
 src/orca/scripts/apps/gcalctool/Makefile
@@ -119,7 +118,6 @@ src/orca/scripts/apps/rhythmbox/Makefile
 src/orca/scripts/apps/soffice/Makefile
 src/orca/scripts/apps/Thunderbird/Makefile
 src/orca/scripts/apps/xfwm4/Makefile
-src/orca/scripts/apps/yelp/Makefile
 src/orca/scripts/toolkits/Makefile
 src/orca/scripts/toolkits/Gecko/Makefile
 src/orca/scripts/toolkits/J2SE-access-bridge/Makefile
diff --git a/src/orca/script_manager.py b/src/orca/script_manager.py
index 62c6cf3..7d0e40d 100644
--- a/src/orca/script_manager.py
+++ b/src/orca/script_manager.py
@@ -57,10 +57,8 @@ class ScriptManager:
              'Miramar':          'Thunderbird',
              'Shredder':         'Thunderbird',
              'bug-buddy':        'gnome_segv2',
-             'epiphany-browser': 'epiphany',
              'gaim':             'pidgin',
              'gnome-calculator': 'gcalctool',
-             'gnome-help':       'yelp',
              'Nereid':           'Banshee',
              'vte':              'gnome-terminal'}
         self._toolkitNames = \
diff --git a/src/orca/scripts/apps/Makefile.am b/src/orca/scripts/apps/Makefile.am
index c915227..d9f9ef5 100644
--- a/src/orca/scripts/apps/Makefile.am
+++ b/src/orca/scripts/apps/Makefile.am
@@ -5,7 +5,6 @@ SUBDIRS = \
 	Eclipse \
 	ekiga \
 	empathy \
-	epiphany \
 	evolution \
 	gajim \
 	gcalctool \
@@ -35,8 +34,7 @@ SUBDIRS = \
 	rhythmbox \
 	soffice \
 	Thunderbird \
-	xfwm4 \
-	yelp
+	xfwm4
 
 orca_pathdir=$(pyexecdir)
 
diff --git a/src/orca/scripts/apps/__init__.py b/src/orca/scripts/apps/__init__.py
index 1cc4b92..9ef9509 100644
--- a/src/orca/scripts/apps/__init__.py
+++ b/src/orca/scripts/apps/__init__.py
@@ -4,7 +4,6 @@ __all__ = ['acroread',
            'Eclipse',
            'ekiga',
            'empathy',
-           'epiphany',
            'evolution',
            'gajim',
            'gcalctool',
@@ -33,5 +32,4 @@ __all__ = ['acroread',
            'rhythmbox',
            'soffice',
            'Thunderbird',
-           'xfwm4',
-           'yelp']
+           'xfwm4']
diff --git a/src/orca/scripts/toolkits/WebKitGtk/script.py b/src/orca/scripts/toolkits/WebKitGtk/script.py
index 3b964b7..1b3a05f 100644
--- a/src/orca/scripts/toolkits/WebKitGtk/script.py
+++ b/src/orca/scripts/toolkits/WebKitGtk/script.py
@@ -1,8 +1,9 @@
 # Orca
 #
 # Copyright (C) 2010-2011 The Orca Team
+# Copyright (C) 2011 Igalia, S.L.
 #
 # Author: Joanmarie Diggs <joanmarie diggs gmail com>
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -22,7 +23,8 @@
 __id__        = "$Id$"
 __version__   = "$Revision$"
 __date__      = "$Date$"
-__copyright__ = "Copyright (c) 2010-2011 The Orca Team"
+__copyright__ = "Copyright (C) 2010-2011 The Orca Team" \
+                "Copyright (C) 2011 Igalia, S.L."
 __license__   = "LGPL"
 
 import pyatspi
@@ -55,7 +57,7 @@ class Script(default.Script):
 
     CARET_NAVIGATION_KEYS = ['Left', 'Right', 'Up', 'Down', 'Home', 'End']
 
-    def __init__(self, app, isBrowser=False):
+    def __init__(self, app, isBrowser=True):
         """Creates a new script for WebKitGtk applications.
 
         Arguments:
@@ -175,6 +177,33 @@ class Script(default.Script):
         types = self.getEnabledStructuralNavigationTypes()
         return StructuralNavigation(self, types, True)
 
+    def getEnabledStructuralNavigationTypes(self):
+        """Returns a list of the structural navigation object types
+        enabled in this script."""
+
+        enabledTypes = [StructuralNavigation.ANCHOR,
+                        StructuralNavigation.BLOCKQUOTE,
+                        StructuralNavigation.BUTTON,
+                        StructuralNavigation.CHECK_BOX,
+                        StructuralNavigation.CHUNK,
+                        StructuralNavigation.COMBO_BOX,
+                        StructuralNavigation.ENTRY,
+                        StructuralNavigation.FORM_FIELD,
+                        StructuralNavigation.HEADING,
+                        StructuralNavigation.LANDMARK,
+                        StructuralNavigation.LIST,
+                        StructuralNavigation.LIST_ITEM,
+                        StructuralNavigation.LIVE_REGION,
+                        StructuralNavigation.PARAGRAPH,
+                        StructuralNavigation.RADIO_BUTTON,
+                        StructuralNavigation.SEPARATOR,
+                        StructuralNavigation.TABLE,
+                        StructuralNavigation.TABLE_CELL,
+                        StructuralNavigation.UNVISITED_LINK,
+                        StructuralNavigation.VISITED_LINK]
+
+        return enabledTypes
+
     def getUtilities(self):
         """Returns the utilites for this script."""
 
@@ -1,8 +1,9 @@
 #
-# Author: Joanmarie Diggs <joanmarie diggs gmail com>
+# Author: Joanmarie Diggs <jdiggs igalia com>
 #
 # This library is free software; you can redistribute it and/or



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]